# Change Log

## [0.3.0](https://github.com/dldevinc/ssi-views/tree/v0.3.0) - 2022-05-28
### ⚠ BREAKING CHANGES
- Dropped support for Python 3.5.

## [0.2.0](https://github.com/dldevinc/ssi-views/tree/v0.2.0) - 2022-01-13
- Add support for Python 3.10
- Add support for Django 3.2, 4.0

## [0.1.1](https://github.com/dldevinc/ssi-views/tree/v0.1.1) - 2021-02-08
- Fix Travis
- Add README.md

## [0.1.0](https://github.com/dldevinc/ssi-views/tree/v0.1.0) - 2021-02-08
- First release
